@@ -1,8 +1,8 @@
 package FFFF;
 use strict;
 
-use FFFF::Config;
 use FFFF::Session;
+use FFFF::Config;
 use LocalCGI;
 use InputCheck;
 
@@ -106,13 +106,19 @@ sub is_error {
 # -------------------------------------------------------------------------
 # å¸
 #
+# TODO:
+# - åطδؿƬˤ줾 SessionType None ν
+#   񤤤ƤΤȤʤС
+#
 # -------------------------------------------------------------------------
 sub session_set {
 	my $self = shift;
 
+	return if ($self->{CONFIG}->{SESSION_TYPE} eq 'NONE');
+
 	my $session = FFFF::Session->new (
-		SESSION_DIR => $self->{CONFIG}->{SESSION_DIR},
-		COOKIE_KEY  => $self->{CONFIG}->{COOKIE_NAME}
+		SESSION_DIR  => $self->{CONFIG}->{SESSION_DIR},
+		COOKIE_KEY   => $self->{CONFIG}->{COOKIE_NAME}
 	);
 
 	
@@ -144,12 +150,18 @@ sub session_set {
 sub session_data {
 	my $self = shift;
 
-	return $self->{SESSION}->get_hash();
+	if ($self->{CONFIG}->{SESSION_TYPE} eq 'NONE') {
+		return %{$self->{FORM}};
+	}
+	else {
+		return $self->{SESSION}->get_hash();
+	}
 }
 
 sub session_expire {
 	my $self = shift;
 
+	return if ($self->{CONFIG}->{SESSION_TYPE} eq 'NONE');
 	return $self->{SESSION}->expire();
 }
 
@@ -160,25 +172,10 @@ sub session_expire {
 sub exec_module {
 	my $self = shift;
 
-	for my $module (@{$self->{CONFIG_NOW}->{MODULE}}) {
-		my $module_name = $module->{NAME};
-		my $config      = $module->{CONFIG};
-
-		#
-		# ⥸塼ɤ߹
-		#
-		my @require = (@{$self->{CONFIG}->{SEARCH_PATH}}, qw(FFFF/Module ./Module));
-		for my $require (@require) {
-			eval { require "$require/mod_${module_name}.pl"; };
-			last unless ($@);
-		}
-		if ($@) {
-			die "Can't locate: mod_${module_name}.pl in search path.(@require)";
-		}
-
-		my $function = "FFFF::Module::${module_name}::execute";
-
-		$self->$function($config);
+	for my $module_obj (@{$self->{CONFIG_NOW}->{MODULE}}) {
+		$module_obj->execute(
+			$self->session_data()
+		);
 	}
 }
 
@@ -203,11 +200,25 @@ sub outputhtml {
 	$template ||= $self->{CONFIG}->{DEFAULT_TEMPLATE};
 	$template = $self->search_template($template);
 
+	#
+	# HIDDEN_LOOP κ
+	#
+	my @hidden_loop;
+	while (my ($name, $value) = each %{$self->{FORM}}) {
+		
+		#
+		# name  Ƭ _ ϤޤΤϥƥѿ
+		#
+		next if ($name =~ /^_/);
+		push(@hidden_loop, {name => $name, value => $value});
+	}
+
 	OutputHtml($template,
 		$self->session_data(),
 		%{$self->{CONFIG}->{DEFAULT_VALUE}},
 		%{$self->{FORM}},
 		%{$self->{ERROR}},
+		_hidden_loop => \@hidden_loop,
 	);
 }
 
@@ -243,10 +254,14 @@ sub search_template {
 
 __END__
 =head CHANGES
+0.0.3   2002/05/21
+	- SessionType  None ΤȤνɲá
+	- Ϥ줿եह٤ƤäƤ hidden_loop Ϥ褦ˤ
+
 0.0.2   2002/05/15
-    - ꤵƤʤ Action äƤ硢åå
-      顼ˤʤХ
+	- ꤵƤʤ Action äƤ硢åå
+	  顼ˤʤХ
 
 0.0.1   2002/05/09
-    - original version
+	- original version
 =cut
