@@ -34,10 +34,13 @@ sub read {
 	#
 	# ƥɤ߹
 	#
-	$config{DEBUG}       = $conf->cmd_config('Debug');
-	$config{DEBUG}       = ($config{DEBUG} =~ /^On$/i)? 1 : 0;
-	$config{SESSION_DIR} = $conf->cmd_config('SessionDir');
-	$config{COOKIE_NAME} = $conf->cmd_config('CookieName');
+	$config{DEBUG}        = $conf->cmd_config('Debug');
+	$config{DEBUG}        = ($config{DEBUG} =~ /^On$/i)? 1 : 0;
+	$config{SESSION_DIR}  = $conf->cmd_config('SessionDir');
+	$config{COOKIE_NAME}  = $conf->cmd_config('CookieName');
+	$config{SESSION_TYPE} = $conf->cmd_config('SessionType');
+	$config{SESSION_TYPE} = ($config{SESSION_TYPE} =~ /^None$/i)? 'NONE' : 'COOKIE';
+
 	eval {
 		$config{SEARCH_PATH} = [
 			'.',
@@ -226,13 +229,25 @@ sub config_module {
 	}
 
 	#
-	# ⥸塼¦ config ƤӽФ
+	# ⥸塼¦ ֥Ȥ
 	#
-	my $function = "FFFF::Module::${key}::config";
-	return map{{NAME => $key, CONFIG => $self->$function($_)}} @{$value};
+	my $module = "FFFF::Module::${key}";
+	my @module;
+	for my $config (@{$value}) {
+		my $obj = $module->new($config);
+		push(@module, $obj);
+	}
+	return @module;
 }
 
 =head CHANGES
+0.0.4   2002/05/22
+	- ⥸塼ϥ֥Ȥ
+
+0.0.3   2002/05/21
+	- SessionType ɲá
+	  ̤ Cookie ȥåȤʤ None
+
 0.0.2   2002/05/14
     - IDENTICAL ΥɬʸˤʤäƤХ
 
