@@ -1,4 +1,5 @@
 package FFFF::Module::csv;
+
 # --------------------------------------------------------------------
 # FFFF::Module::csv 
 # - CSVǡ¸
@@ -6,9 +7,7 @@ package FFFF::Module::csv;
 #
 # --------------------------------------------------------------------
 use strict;
-use POSIX qw(strftime);
-$FFFF::Module::csv::TIME = time();
-
+use base qw(FFFF::Module::Base);
 
 require "jcode.pl";
 
@@ -58,13 +57,24 @@ sub config {
 	#
 	# ¸
 	#
-	$config{SEPARATE} = ($config->{separate}->[0]->[0] =~ /^tab$/i)? 'TAB' : "";
+	$config{SEPARATE} = ($config->{separate}->[0]->[0] =~ /^tab$/i)? "\t" : ",";
+
 
 	#
 	# ¸ʸ
 	#
-	$config{CHAR_SET} = $config->{charset}->[0]->[0] || 'Shift_JIS';
-	
+	$config{CHAR_SET} = $config->{charset}->[0]->[0];
+	if ($config{CHAR_SET} =~ /^Shift_JIS$/i) {
+		$config{CHAR_SET} = 'sjis';
+	}
+	elsif ($config{CHAR_SET} =~ /^EUC-JP$/i) {
+		$config{CHAR_SET} = 'euc';
+	}
+	elsif ($config{CHAR_SET} =~ /^ISO-2022-JP$/i) {
+		$config{CHAR_SET} = 'jis';
+	}
+	$config{CHAR_SET} ||= 'sjis';
+
 
 	#
 	# ԥ(LF, CF)̵뤹뤫ɤ
@@ -73,7 +83,7 @@ sub config {
 	$config{DELETE_BREAK} = $config->{deletebreak}->[0]->[0];
 	$config{DELETE_BREAK} = ($config{DELETE_BREAK} =~ /^Off$/i)? 0 : 1;
 
-	return \%config;
+	$self->{CONFIG} = \%config;
 }
 
 # --------------------------------------------------------------------
@@ -83,64 +93,28 @@ sub config {
 # --------------------------------------------------------------------
 sub execute {
 	my $self     = shift;
-	my ($config) = @_;
+	my (%form) = @_;
+
+	my $config = $self->{CONFIG};
 
 	#
-	# å󤫤ǡ
+	# ե륿Υå
 	#
-	my %session = $self->session_data();
+	$self->set_filter();
+
 
 	#
 	# ե̾
 	#
 	my $file = $config->{FILE};
-	$file =~ s/{FORM:(.+?)}/$session{$1}/g;
-	$file =~ s/{(\w+):(.+)}/$self->FFFF::Module::csv::filter($1, $2)/eg;
+	$file =~ s/{FORM:(.+?)}/$form{$1}/g;
+	$file =~ s/{(\w+):(.+)}/$self->{FILTER}->execute($1, $2)/eg;
+
 
 	#
 	# ¸ܤμ
 	#
-	my @save = map {@$_} $config->{SAVE};
-	for my $save (@save) {
-		#
-		# եफ
-		#
-		if ($save =~ /^(\w+)$/) {
-			$save = $session{$1};
-		}
-
-		#
-		# ե륿
-		#
-		else {
-			$save =~ s/{FORM:(.+?)}/$session{$1}/g;
-			$save =~ s/{(\w+):(.*?)}/$self->FFFF::Module::csv::filter($1, $2)/eg;
-		}
-	}
-
-	#
-	# ʸ
-	#
-	if ($config->{DELETE_BREAK} == 1) {
-		for (@save) { s/\n|\r//g; }
-	}
-
-
-	#
-	# ¸ʸ
-	# ϡ˿ʽФĤʤ餳դϳ٤
-	# Perl 5.8 ǥݡȤ Encode ⥸塼Ȥ٤?
-	#
-	my $char_set;
-	if ($config->{CHAR_SET} =~ /^Shift_JIS$/) {
-		$char_set = 'sjis';
-	}
-	elsif ($config->{CHAR_SET} =~ /^EUC-JP$/) {
-		$char_set = 'euc';
-	}
-	elsif ($config->{CHAR_SET} =~ /^ISO-2022-JP$/) {
-		$char_set = 'jis';
-	}
+	my @save = $self->get_save_data(%form);
 
 
 	#
@@ -154,15 +128,9 @@ sub execute {
 	# ե뤬 0 ХȤǥإåƤإå
 	#
 	if ((stat CSV)[7] == 0 and ref $config->{HEADER} eq "ARRAY") {
-		my $header;
-		if ($config->{SEPARATE} eq 'TAB') {
-			$header = join "\t", map {@$_} $config->{HEADER};
-		}
-		else {
-			$header = join ",", map {@$_} $config->{HEADER};
-		}
-		
-		$header = jcode::to($char_set, $header, "euc");
+
+		my $header = join $config->{SEPARATE}, map {@$_} $config->{HEADER};
+		$header = jcode::to($config->{CHAR_SET} , $header, "euc");
 		print CSV "$header\n";
 	}
 
@@ -170,7 +138,7 @@ sub execute {
 	# TABڤѴƥե¸
 	#
 	my $line;
-	if ($config->{SEPARATE} eq 'TAB') {
+	if ($config->{SEPARATE} eq "\t") {
 		$line = join "\t", map {s/\t//g; $_} @save;
 	}
 
@@ -182,7 +150,7 @@ sub execute {
 		$line = join ",", map {(s/"/""/g or /[\r\n,]/)? qq{"$_"} : $_} @save;
 	}
 
-	$line = jcode::to($char_set, $line, "euc");
+	$line = jcode::to($config->{CHAR_SET}, $line, "euc");
 	print CSV "$line\n";
 
 	flock(CSV, 8);
@@ -190,47 +158,54 @@ sub execute {
 }
 
 # --------------------------------------------------------------------
-# ե륿
+# ¸ܤμ
 #
 # --------------------------------------------------------------------
-sub filter {
+sub get_save_data {
 	my $self     = shift;
-	my ($filter_name, $value) = @_;
+	my (%form) = @_;
 
-	my $func = "FFFF::Module::csv::filter_${filter_name}";
-
-	return $self->$func($value);
-}
-
-sub filter_ENV {
-	my $self  = shift;
-	my ($key) = @_;
-
-	return $ENV{$key};
-}
-
-sub filter_TIME {
-	my $self  = shift;
-	my ($format) = @_;
+	my $config = $self->{CONFIG};
 
 	#
-	# Solaris  %s бƤʤк
+	# ¸ܤμ
 	#
-	$format =~ s/\%s/$FFFF::Module::csv::TIME/g;
+	my @save = map {@$_} $config->{SAVE};
+	for my $save (@save) {
 
-	return strftime($format, localtime($FFFF::Module::csv::TIME));
-}
+		#
+		# եफ
+		#
+		if ($save =~ /^(\w+)$/) {
+			$save = $form{$1};
+		}
 
-sub filter_STR {
-	my $self  = shift;
-	my ($value) = @_;
+		#
+		# ե륿
+		#
+		else {
+			$save =~ s/{FORM:(.+?)}/$form{$1}/g;
+			$save =~ s/{(\w+):(.*?)}/$self->{FILTER}->execute($1, $2)/eg;
+		}
+	}
 
-	return  $value;
+	#
+	# ʸ
+	#
+	if ($config->{DELETE_BREAK} == 1) {
+		for (@save) { s/\n|\r//g; }
+	}
+
+	return @save;
 }
 
 1;
 __END__
 =head CHANGES
+0.0.4   2002/05/21
+	- ⥸塼Υ֥Ȳ
+	- ե륿Υ⥸塼벽
+
 0.0.3   2002/05/15
 	- ʸɤλб
 "CharSet  EUC-JP" ͤ˻ꤷޤ
