@@ -7,9 +7,9 @@ package FFFF::Module::db;
 # --------------------------------------------------------------------
 use strict;
 use DBI;
-use POSIX qw(strftime);
 
-$FFFF::Module::db::TIME = time();
+use base qw(FFFF::Module::Base);
+use FFFF::Module::Filter;
 
 # --------------------------------------------------------------------
 # եβ
@@ -90,7 +90,7 @@ sub config {
 	}
 	$config{INSERT} = \@insert;
 
-	return \%config;
+	$self->{CONFIG} = \%config;
 }
 
 # --------------------------------------------------------------------
@@ -99,14 +99,15 @@ sub config {
 #
 # --------------------------------------------------------------------
 sub execute {
-	my $self     = shift;
-	my ($config) = @_;
+	my $self   = shift;
+	my (%form) = @_;;
 
-	#
-	# å󤫤ǡ
-	#
-	my %session = $self->session_data();
+	my $config = $self->{CONFIG};
 
+    #
+    # ե륿Υå
+    #
+    $self->set_filter();
 
 	#
 	# DB ³
@@ -134,15 +135,15 @@ sub execute {
 			# եफ
 			#
 			if ($bind =~ /^(\w+)$/) {
-				$bind = $session{$1};
+				$bind = $form{$1};
 			}
 
 			#
 			# ե륿
 			#
 			else {
-				$bind =~ s/{FORM:(.+?)}/$session{$1}/g;
-				$bind =~ s/{(\w+):(.*?)}/$self->FFFF::Module::db::filter($1, $2)/eg;
+				$bind =~ s/{FORM:(.+?)}/$form{$1}/g;
+				$bind =~ s/{(\w+):(.*?)}/$self->{FILTER}->execute($1, $2)/eg;
 			}
 		}
 
@@ -167,49 +168,13 @@ sub execute {
 	$dbh->disconnect();
 }
 
-# --------------------------------------------------------------------
-# ե륿
-#
-# --------------------------------------------------------------------
-sub filter {
-	my $self     = shift;
-	my ($filter_name, $value) = @_;
-
-	my $func = "FFFF::Module::db::filter_${filter_name}";
-
-	return $self->$func($value);
-}
-
-sub filter_ENV {
-	my $self  = shift;
-	my ($key) = @_;
-
-	return $ENV{$key};
-}
-
-sub filter_TIME {
-	my $self  = shift;
-	my ($format) = @_;
-
-    #
-    # Solaris  %s бƤʤк
-    #
-    $format =~ s/\%s/$FFFF::Module::db::TIME/g;
-
-	return strftime($format, localtime($FFFF::Module::db::TIME));
-}
-
-sub filter_STR {
-	my $self  = shift;
-	my ($value) = @_;
-
-	return  $value;
-}
-
-
 1;
 
 =head CHANGES
+0.0.3   2002/05/22
+    - ⥸塼Υ֥Ȳ
+    - ե륿Υ⥸塼벽
+
 0.0.2   2002/05/16
     - strftime  %s(1970ΥեåáSolarisбƤʤΤ
       б
