@@ -7,6 +7,8 @@ package FFFF::Module::mail;
 #
 # --------------------------------------------------------------------
 use strict;
+use base qw(FFFF::Module::Base);
+
 use POSIX qw(strftime);
 use LocalCGI;
 
@@ -26,6 +28,8 @@ use constant HEADER_FIELD => [qw(
 )];
 
 
+
+
 # --------------------------------------------------------------------
 # եβ
 #
@@ -116,7 +120,7 @@ sub config {
 		}
 	}
 
-	return \%config;
+	$self->{CONFIG} = \%config;
 }
 
 # --------------------------------------------------------------------
@@ -127,12 +131,9 @@ sub config {
 # --------------------------------------------------------------------
 sub execute {
 	my $self     = shift;
-	my ($config) = @_;
+	my (%form) = @_;
 
-	#
-	# å󤫤ǡ
-	#
-	my %data = $self->session_data();
+	my $config = $self->{CONFIG};
 
 	#
 	# ե뤫ǡ 
@@ -140,15 +141,16 @@ sub execute {
 	for my $header_field (map{@$_} HEADER_FIELD) {
 		my $cf = $config->{uc $header_field};
 		if (ref $cf eq "HASH") {
-			$data{lc $header_field} = $cf->{DATA}->{$data{$cf->{KEY}}};
+			$form{lc $header_field} = $cf->{DATA}->{$form{$cf->{KEY}}};
 		}
 	}
 
+
 	#
 	# ƥץ졼ȤŸ
 	#
-	my $template = $self->search_template($config->{TEMPLATE});
-	my $mail = OutputTemplate($template, %data);
+	my $mail = $self->get_mail_source(%form);
+
 
 	#
 	# ե¸
@@ -174,12 +176,25 @@ sub execute {
 	}
 }
 
+# --------------------------------------------------------------------
+# ᡼ʸμ
+#
+# --------------------------------------------------------------------
+sub get_mail_source {
+	my $self   = shift;
+	my (%form) = @_;
+
+	return OutputTemplate($self->{CONFIG}->{TEMPLATE}, %form);
+}
+
 1;
 =head CHANGES
-0.0.2   2002/05/15
-    - SendmailץͭˤʤäƤʤäХ
+0.0.3   2002/05/22
+	- ⥸塼Υ֥Ȳ
 
+0.0.2   2002/05/15
+	- SendmailץͭˤʤäƤʤäХ
 
 0.0.1   2002/05/09
-    - original version
+	- original version
 =cut
